@@ -1,13 +1,14 @@
 #!/usr/bin/env python
 # encoding: utf-8
 
+from datetime import datetime, timedelta
 from email.mime.multipart import MIMEMultipart
 from email.mime.base import MIMEBase
 from email.mime.text import MIMEText
-from multiprocessing.pool import Pool
+from multiprocessing import Pool
 
-from .. import CONFIG
 from .. import core
+from ..consts import CONFIG, REDIS_DB
 from ..customer import Customer
 from ..product import Product
 from ..product_gp import Product_GP
@@ -38,7 +39,7 @@ def sync():
     products = Product.all()
     for product in products:
         product.update_customers()
-        with Pool(2) as pool:
+        with Pool(processes=2) as pool:
             pool.map(core.update_customer_cdr, product.customers)
 
 
@@ -54,13 +55,11 @@ def notify():
         if not response:
             click.echo("Pas de notification à envoyer")
         else:
-            medium, percentage = response
-            click.echo(
-                '{}: {}% (Notification envoyée)'.format(
-                    medium,
-                    percentage
-                    )
-                )
+            medium, percentage, status = response
+            msg = '{}: {}%'.format(medium, round(percentage))
+            if status:
+                msg = '{} ({})'.format(msg, 'Notification envoyée')
+            click.echo(msg)
 
 
 @cmd.command()
@@ -103,10 +102,16 @@ def apply(append_details, for_real, send_mail):
                 for customer, data in policy['customers'].items():
                     customer_policies_status = Customer(customer).fup_status
                     policy_status = False
-                    for customer_policy_status in customer_policies_status:
-                        if customer_policy_status['policy'] == policy['name']:
-                            policy_status = customer_policy_status['status']
-                            break
+                    customer_policy_status = customer_policies_status.get(
+                        policy['name']
+                        )
+                    if customer_policy_status:
+                        customer_policy_status = sorted(
+                            customer_policy_status,
+                            key=lambda x: x['datetime'],
+                            reverse=True
+                            )
+                        policy_status = customer_policy_status[0]['status']
                     dataset.append(
                         [
                             product,
@@ -167,4 +172,95 @@ def apply(append_details, for_real, send_mail):
                 )
             s.quit()
 
+
+@cmd.command()
+@click.option('--start')
+@click.option('--stop')
+@click.option('--send-mail')
+def details(start, stop, send_mail):
+    """Renvoie le détail de consommation des clients"""
+    if not stop:
+        stop = datetime.now() - timedelta(1)
+    if not start:
+        start = datetime.now() - timedelta(30)
+    dataset = tablib.Dataset()
+    dataset.headers = ['client', 'produit', 'politique_fup', 'total']
+    date = start
+    while date <= stop:
+        dataset.headers.append(date.strftime('%d%m%Y'))
+        date += timedelta(1)
+    customers = Customer.all()
+    cdrs = {}
+    with click.progressbar(customers) as _customers:
+        for customer in _customers:
+            key = 'cdr_start_date:{}'.format(customer.name)
+            _start = REDIS_DB.get(key)  # s'il n'y a pas de clés ce sera None
+            if _start:
+                _start = _start.decode('utf-8')
+                start = datetime.strptime(
+                    _start + ' 00:00:00', '%d%m%Y %H:%M:%S'
+                    )
+            msg = '> Conso de {} du {} au {}'.format(
+                customer.name,
+                start.strftime('%d/%m/%Y'),
+                stop.strftime('%d/%m/%Y')
+                )
+            click.echo(msg)
+            cdrs[customer.name] = {
+                'product': customer.product.name,
+                'cdrs': customer.filter_cdrs_policy_wise(
+                    customer.get_cdr(start=start, stop=stop)
+                    )
+                }
+    for customer, infos in cdrs.items():
+        product = infos['product']
+        data = infos['cdrs']
+        for policy_cdrs in data:
+            policy_name = policy_cdrs['name']
+            total = round(
+                policy_cdrs['total']/1000000000, 2
+                )
+            line = [customer, product, policy_name, total]
+            for date in dataset.headers[4:]:
+                for cdr in policy_cdrs['details']:
+                    if cdr['date'] == date:
+                        line.append(
+                            round(
+                                cdr['total']/1000000000, 2
+                                )
+                            )
+                        break
+                else:
+                    line.append(0)
+            dataset.rpush(line)
+    with open('/tmp/conso.csv', 'w') as f:
+        f.write(dataset.export('csv'))
+    if send_mail:
+        message = "Consommation des clients du {} au {}".format(
+            start.strftime('%d%m%Y'),
+            stop.strftime('%d%m%Y')
+            )
+        content = MIMEText(message, 'plain', 'utf-8')
+        attachment = MIMEBase('text', 'csv')
+        fp = open('/tmp/conso.csv', 'rb')
+        attachment.set_payload(fp.read())
+        fp.close()
+        attachment.add_header(
+            'Content-Disposition',
+            'attachment',
+            filename='conso.csv'
+            )
+        msg = MIMEMultipart()
+        msg['Subject'] = "Détails de consommation FUP"
+        msg['From'] = CONFIG['ALERT']['from']
+        msg['To'] = send_mail
+        msg.attach(attachment)
+        msg.attach(content)
+        s = smtplib.SMTP('localhost')
+        s.sendmail(
+            CONFIG['ALERT']['from'],
+            send_mail.replace(' ', '').split(','),
+            msg.as_string()
+            )
+        s.quit()
 # EOF
