@@ -37,6 +37,17 @@ def database_url(**kwargs):
     return url
 
 
+def purge_customer(name):
+    url = database_url(**FUPDB_CREDENTIALS)
+    with records.Database(url) as db:
+        sql = "DELETE FROM customer WHERE name=:name"
+        db.query(sql, name=name)
+        sql = "DELETE FROM cdr WHERE customer=:name"
+        db.query(sql, name=name)
+        sql = "DELETE FROM fup WHERE customer=:name"
+        db.query(sql, name=name)
+
+
 def record_customer(infos):
     url = database_url(**FUPDB_CREDENTIALS)
     with records.Database(url) as db:
@@ -56,9 +67,7 @@ def apply_product_policies(for_real, customer):
     """Sous routine appliquant les politiques de bon usage
     à un client en particulier.
     Utile pour ensuite faire de l'exécution parallèle"""
-    response = customer.apply_product_policies(
-        for_real=for_real
-        )
+    response = customer.apply_product_policies(for_real=for_real)
     data = [
         policy for policy in response
         # if 'fup_in' in policy or 'fup_out' in policy
